pyparsing.pyparsing.TokenConverter

Package pyparsing :: Module pyparsing :: Class TokenConverter |
[frames | no frames]

## Type TokenConverter

         object --+
                  |
      ParserElement --+
                      |
    ParseElementEnhance --+
                          |
                         TokenConverter

Known Subclasses:
  `Combine`, `Dict`, `Group`, `Suppress`, `Upcase`

Abstract subclass of ParseExpression, for converting parsed results.

Method Summary
| `__init__(self, expr, savelist)`
Inherited from `ParseElementEnhance`: `__str__`, `checkRecursion`, `ignore`, `leaveWhitespace`, `parseImpl`, `streamline`, `validate` Inherited from `ParserElement`: `__add__`, `__and__`, `__call__`, `__eq__`, `__getattr__`, `__invert__`, `__mul__`, `__or__`, `__radd__`, `__rand__`, `__repr__`, `__req__`, `__rmul__`, `__ror__`, `__rxor__`, `__xor__`, `addParseAction`, `copy`, `enablePackrat`, `getException`, `parseFile`, `parseString`, `parseWithTabs`, `postParse`, `preParse`, `resetCache`, `scanString`, `searchString`, `setBreak`, `setDebug`, `setDebugActions`, `setDefaultWhitespaceChars`, `setFailAction`, `setName`, `setParseAction`, `setResultsName`, `setWhitespaceChars`, `suppress`, `transformString`, `tryParse` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variable Summary
Inherited from `ParserElement`: `DEFAULT_WHITE_CHARS`

Generated by Epydoc 2.1 on Sun Feb 10 18:01:06 2008 | http://epydoc.sf.net